import { CharacterClassifier } from './characterClassifier.js';

declare const enum WordCharacterClass {
    Regular = 0,
    Whitespace = 1,
    WordSeparator = 2
}
declare class WordCharacterClassifier extends CharacterClassifier<WordCharacterClass> {
    readonly intlSegmenterLocales: Intl.UnicodeBCP47LocaleIdentifier[];
    constructor(wordSeparators: string, intlSegmenterLocales: Intl.UnicodeBCP47LocaleIdentifier[]);
    findPrevIntlWordBeforeOrAtOffset(line: string, offset: number): IntlWordSegmentData | null;
    findNextIntlWordAtOrAfterOffset(lineContent: string, offset: number): IntlWordSegmentData | null;
    private _getIntlSegmenterWordsOnLine;
}
interface IntlWordSegmentData {
    /** A string containing the segment extracted from the original input string. */
    segment: string;
    /** The code unit index in the original input string at which the segment begins. */
    index: number;
    /** The complete input string that was segmented. */
    input: string;
    /**
     * A boolean value only if granularity is "word"; otherwise, undefined.
     * If granularity is "word", then isWordLike is true when the segment is word-like (i.e., consists of letters/numbers/ideographs/etc.); otherwise, false.
     */
    isWordLike: true;
}

export { type IntlWordSegmentData, WordCharacterClass, WordCharacterClassifier };
